@@ -4,8 +4,7 @@ from typing import Final
 
 from ecowitt2mqtt.helpers.typing import UnitSystemType
 
-__version__ = "2022.08.3"
-
+__version__ = "2022.09.0"
 
 LOGGER = logging.getLogger(__package__)
 
@@ -16,6 +15,7 @@ CONF_DEFAULT_BATTERY_STRATEGY: Final = "default_battery_strategy"
 CONF_DIAGNOSTICS: Final = "diagnostics"
 CONF_DISABLE_CALCULATED_DATA: Final = "disable_calculated_data"
 CONF_ENDPOINT: Final = "endpoint"
+CONF_GATEWAYS: Final = "gateways"
 CONF_HASS_DISCOVERY: Final = "hass_discovery"
 CONF_HASS_DISCOVERY_PREFIX: Final = "hass_discovery_prefix"
 CONF_HASS_ENTITY_ID_PREFIX: Final = "hass_entity_id_prefix"
@@ -32,6 +32,7 @@ CONF_PORT: Final = "port"
 CONF_RAW_DATA: Final = "raw_data"
 CONF_VERBOSE: Final = "verbose"
 
+
 # Data points (glob):
 DATA_POINT_GLOB_BAROM: Final = "barom"
 DATA_POINT_GLOB_BATT: Final = "batt"
@@ -118,8 +119,14 @@ DATA_POINT_WS90_VER: Final = "ws90_ver"
 DATA_POINT_YEARLY_RAIN: Final = "yearlyrain"
 DATA_POINT_YRAIN_PIEZO: Final = "yrain_piezo"
 
+# Defaults:
+DEFAULT_ENDPOINT: Final = "/data/report"
+DEFAULT_HASS_DISCOVERY_PREFIX: Final = "homeassistant"
+DEFAULT_MQTT_PORT: Final = 1883
+DEFAULT_PORT: Final = 8080
+
 # Environment variables:
-ENV_BATTERY_OVERRIDE: Final = "ECOWITT2MQTT_BATTERY_OVERRIDE"
+ENV_BATTERY_OVERRIDES: Final = "ECOWITT2MQTT_BATTERY_OVERRIDE"
 ENV_CONFIG: Final = "ECOWITT2MQTT_CONFIG"
 ENV_DEFAULT_BATTERY_STRATEGY: Final = "ECOWITT2MQTT_DEFAULT_BATTERY_STRATEGY"
 ENV_DIAGNOSTICS: Final = "ECOWITT2MQTT_DIAGNOSTICS"
@@ -160,6 +167,7 @@ LEGACY_ENV_RAW_DATA: Final = "RAW_DATA"
 # Unit systems:
 UNIT_SYSTEM_IMPERIAL: UnitSystemType = "imperial"
 UNIT_SYSTEM_METRIC: UnitSystemType = "metric"
+UNIT_SYSTEMS: Final = [UNIT_SYSTEM_IMPERIAL, UNIT_SYSTEM_METRIC]
 
 # Degree units
 DEGREE: Final = "°"
